<?php

/**
  * Login for admin panel, login.php
  * @category admin
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */

include(dirname(__FILE__).'/../config/config.inc.php');
include(dirname(__FILE__).'/functions.php');

$errors = array();

/* Check security problems
if (in_array('install', scandir(dirname(__FILE__).'/../')))
	$errors[] = 'installation directory must be deleted';
if (substr(dirname(__FILE__), -5) == 'admin')
	$errors[] = 'admin directory must be renamed';
*/

$cookie = new Cookie('psAdmin', substr($_SERVER['PHP_SELF'], strlen(__PS_BASE_URI__), -10));

switch (strtolower(Tools::setCookieLanguage()))
{
	case 'fr':
		$l = array(
		'Administration panel' => 'Panneau d\'administration', 
		'There are' => 'Il y a', 
		'There is' => 'Il y a',
		'errors' => 'erreurs', 
		'error' => 'erreur', 
		'Email address:' => 'Adresse e-mail :',
		'Password:' => 'Mot de passe : ', 
		'stay connected' => 'se souvenir de moi', 
		'Connection' => 'Connexion', 
		'Lost password?' => 'Mot de passe oubli&eacute; ?'
		);
	break;
	case 'en':
	default:
		$l = array(
		'Administration panel' => 'Administration panel', 
		'There are' => 'There are', 
		'There is' => 'There is', 
		'errors' => 'errors',
		'error'	=> 'error', 
		'Email address:' => 'Email address:',
		'Password:' => 'Password:', 
		'stay connected' => 'stay connected', 
		'Connection' => 'Connection', 
		'Lost password?' => 'Lost password?'
		);
}


/* These errors are fatal */
if (sizeof($errors))
	die(displayErrors($errors));

/* Cookie creation and redirection */
if (Tools::isSubmit('Submit'))
{
 	/* Check fields validity */
	$passwd = trim(Tools::getValue('passwd'));
	$email = trim(Tools::getValue('email'));
	if (empty($email))
		$errors[] = Tools::displayError('email is empty');
	elseif (!Validate::isEmail($email))
		$errors[] = Tools::displayError('invalid e-mail address');
	elseif (empty($passwd))
		$errors[] = Tools::displayError('password is empty');
	elseif (!Validate::isPasswd($passwd))
		$errors[] = Tools::displayError('invalid password');
	else
	{
	 	/* Seeking for employee */
		$employee = new Employee();
		$employee = $employee->getByEmail($email, $passwd);
		if (!$employee)
		{
			$errors[] = Tools::displayError('employee doesn\'t exist or bad password');
			$cookie->logout();
		}
		else
		{
		 	/* Creating cookie */
			if (isset($_POST['rememberme']))
				$cookie->setExpire(time() + 1728000); /* 20 days */
			$cookie->id_employee = $employee->id;
			$cookie->name = $employee->name;
			$cookie->surname = $employee->surname;
			$cookie->email = $employee->email;
			$cookie->is_admin = $employee->is_admin;
			$cookie->profile = $employee->id_profile;
			$cookie->passwd = $employee->passwd;
			$cookie->write();

			/* Redirect to admin panel */
			if (isset($_GET['redirect']))
				$url = strval ($_GET['redirect']);
			else
				$url = dirname ($_SERVER['PHP_SELF']).'/index.php';
			Tools::redirect($url, '');
		}
	}
}

echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="fr" lang="fr">
	<head>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link type="text/css" rel="stylesheet" href="../css/login.css" />
		<title>PrestaShop&trade; - '.$l['Administration panel'].'</title>
	</head>
	<body>
		<div id="container">';

if ($nbErrors = sizeof($errors))
{
	echo '
	<div id="error">
		<h3>'.($nbErrors > 1 ? $l['There are'] : $l['There is']).' '.$nbErrors.' '.($nbErrors > 1 ? $l['errors'] : $l['error']).'</h3>
		<ol style="margin: 0 0 0 20px;">';
		foreach ($errors AS $error)
			echo '<li>'.$error.'</li>';
		echo '
		</ol>
	</div>
	<br />';
}

echo '
			<div id="login">
				<form action="" method="post">
					<label>'.$l['Email address:'].'</label><br />
					<input type="text" name="email" value="'.(isset($_POST['email']) ? $_POST['email'] : '').'" class="input" />
					<div style="margin: 0.5em 0 0 0;">
						<label>'.$l['Password:'].'</label><br />
						<input type="password" name="passwd" class="input" />
					</div>
					<div style="margin: 0.5em 0 0 0;"><input type="checkbox" name="rememberme" checked="checked"/> '.$l['stay connected'].'</div>
					<div>
						<div id="submit"><input type="submit" name="Submit" value="'.$l['Connection'].'" class="button" /></div>
						<div id="lost"><a href="password.php">'.$l['Lost password?'].'</a></div>
					</div>
				</form>
			</div>
		</div>
	</body>
</html>';

?>