<?php

/**
  * Addresses tab for admin panel, AdminAddresses.php
  * @category admin
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */

class AdminAddresses extends AdminTab
{
	/** @var array countries list */
	private $countriesArray = array();
	
	public function __construct()
	{
	 	global $cookie;
	 	
	 	$this->table = 'address';
	 	$this->className = 'Address';
	 	$this->lang = false;
	 	$this->edit = true;
		if (!Tools::getValue('realedit'))
			$this->deleted = true;
		$this->_select = 'cl.`name` as country';
		$this->_join = 'LEFT JOIN `'._DB_PREFIX_.'country_lang` cl ON 
		(cl.`id_country` = a.`id_country` AND cl.`id_lang` = '.intval($cookie->id_lang).')';
		
		$countries = Country::getCountries(intval($cookie->id_lang));
		foreach ($countries AS $country)
			$this->countriesArray[$country['id_country']] = $country['name'];
				
		$this->fieldsDisplay = array(
		'id_address' => array('title' => $this->l('ID'), 'align' => 'center', 'width' => 25),
		'surname' => array('title' => $this->l('Surname'), 'width' => 80),
		'name' => array('title' => $this->l('Name'), 'width' => 100, 'filter_key' => 'a!name'),
		'address1' => array('title' => $this->l('Address'), 'width' => 200),
		'postcode' => array('title' => $this->l('Postcode'), 'align' => 'right', 'width' => 50),
		'city' => array('title' => $this->l('City'), 'width' => 150),
		'country' => array('title' => $this->l('Country'), 'width' => 100, 'type' => 'select', 'select' => $this->countriesArray, 'filter_key' => 'cl!id_country'));
	
		parent::__construct();
	}
	
	public function postProcess()
	{
		if (isset($_POST['submitAdd'.$this->table]))
		{
			/* Transform email in id_customer for parent processing */
			if (Validate::isEmail(Tools::getValue('email')))
			{
				$customer = new Customer;
				$customer = $customer->getByEmail(Tools::getValue('email'));
				if (Validate::isLoadedObject($customer))
					$_POST['id_customer'] = $customer->id;
				else
					$this->_errors[] = Tools::displayError('this e-mail is not registered');
			}
			else
				$this->_errors[] = Tools::displayError('customer e-mail is not valid');
		}
		if (!sizeof($this->_errors))
			parent::postProcess();
	}
	
	public function displayForm()
	{
		global $currentIndex;
		$obj = $this->loadObject(true);
		/* Get customer email by id_customer */
		if ($obj->id AND !Tools::getValue('email'))
		{
			$customer = new Customer($obj->id_customer);
			$_POST['email'] = $customer->email;
		}
		
		echo '
		<form action="'.$currentIndex.'&submitAdd'.$this->table.'=1" method="post">
		'.($obj->id ? '<input type="hidden" name="id_'.$this->table.'" value="'.$obj->id.'" />' : '').'
		'.(($id_order = intval(Tools::getValue('id_order'))) ? '<input type="hidden" name="id_'.$this->table.'" value="'.$id_order.'" />' : '').'
		'.(Tools::getValue('realedit') ? '<input type="hidden" name="realedit" value="1" />' : '').'
			<fieldset><legend><img src="../img/admin/contact.gif" />'.$this->l('Addresses').'</legend>
				<label>'.$this->l('Customer e-mail:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="email" value="'.Tools::getValue('email').'" style="text-transform: lowercase;" /> <sup>*</sup>
				</div>
				<label>'.$this->l('Alias:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="alias" value="'.$this->getFieldValue($obj, 'alias').'" />
					<span class="hint" name="help_box">'.$this->l('Forbidden characters:').' <>;=#{}<span class="hint-pointer">&nbsp;</span></span>
				</div>
				<label>'.$this->l('Company:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="company" value="'.$this->getFieldValue($obj, 'company').'" />
					<span class="hint" name="help_box">'.$this->l('Forbidden characters:').' <>;=#{}<span class="hint-pointer">&nbsp;</span></span>
				</div>
				<label>'.$this->l('Name:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="name" value="'.$this->getFieldValue($obj, 'name').'" style="text-transform: uppercase;" /> <sup>*</sup>
					<span class="hint" name="help_box">'.$this->l('Forbidden characters:').' 0-9!<>,;?=+()@#"{}_$%:<span class="hint-pointer">&nbsp;</span></span>
				</div>
				<label>'.$this->l('Surname:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="surname" value="'.$this->getFieldValue($obj, 'surname').'" /> <sup>*</sup>
					<span class="hint" name="help_box">'.$this->l('Forbidden characters:').' 0-9!<>,;?=+()@#"{}_$%:<span class="hint-pointer">&nbsp;</span></span>
				</div>
				<label>'.$this->l('Address:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="address1" value="'.$this->getFieldValue($obj, 'address1').'" /> <sup>*</sup>
				</div>
				<label>'.$this->l('Address').' (2):</label>
				<div class="margin-form">
					<input type="text" size="33" name="address2" value="'.$this->getFieldValue($obj, 'address2').'" />
				</div>
				<label>'.$this->l('Postcode:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="postcode" value="'.$this->getFieldValue($obj, 'postcode').'" /> <sup>*</sup>
				</div>
				<label>'.$this->l('City:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="city" value="'.$this->getFieldValue($obj, 'city').'" style="text-transform: uppercase;" /> <sup>*</sup>
				</div>
				<label>'.$this->l('Country:').'</label>
				<div class="margin-form">
					<select name="id_country" />';
		foreach ($this->countriesArray AS $id_country => $name)
			echo '		<option value="'.$id_country.'"'.(($this->getFieldValue($obj, 'id_country') == $id_country) ? ' selected="selected"' : '').'>'.$name.'</option>';
		echo '		</select> <sup>*</sup>
				</div>
				<label>'.$this->l('Home phone:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="phone" value="'.$this->getFieldValue($obj, 'phone').'" />
				</div>
				<label>'.$this->l('Mobile phone:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="phone_mobile" value="'.$this->getFieldValue($obj, 'phone_mobile').'" />
				</div>
				<label>'.$this->l('Other:').'</label>
				<div class="margin-form">
					<textarea name="other">'.$this->getFieldValue($obj, 'other').'</textarea>
					<span class="hint" name="help_box">'.$this->l('Forbidden characters:').' <>;=#{}<span class="hint-pointer">&nbsp;</span></span>
				</div>
				<div class="margin-form">
					<input type="submit" value="'.$this->l('   Save   ').'" name="submitAdd'.$this->table.'" class="button" />
				</div>
				<div class="small"><sup>*</sup> '.$this->l('required fields').'</div>
			</fieldset>
		</form>';
	}
}

?>
