<?php

/**
  * Orders tab for admin panel, AdminOrders.php
  * @category admin
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */
  
class AdminOrders extends AdminTab
{
	public function __construct()
	{	
	 	$this->table = 'order';
	 	$this->className = 'Order';
	 	$this->view = true;
	 	$this->_select = 'CONCAT(c.`surname`, \' \', c.`name`) AS `customer`, osl.`name` AS `osname`, os.`color`';
	 	$this->_join = 'LEFT JOIN `'._DB_PREFIX_.'customer` c ON (c.`id_customer` = a.`id_customer`) 
	 	LEFT JOIN `'._DB_PREFIX_.'order_history` oh ON (oh.`id_order` = a.`id_order`) 
		LEFT JOIN `'._DB_PREFIX_.'order_state` os ON (os.`id_order_state` = oh.`id_order_state`) 
		LEFT JOIN `'._DB_PREFIX_.'order_state_lang` osl ON (os.`id_order_state` = osl.`id_order_state` AND osl.`id_lang` = a.`id_lang`)';
		$this->_where = 'AND oh.`id_order_history` = (SELECT MAX(`id_order_history`) FROM `'._DB_PREFIX_.'order_history` moh WHERE moh.`id_order` = a.`id_order` GROUP BY moh.`id_order`)';
		$this->_group = 'GROUP BY oh.id_order';
		
		global $cookie;
		$statesArray = array();
		$states = OrderState::getOrderStates(intval($cookie->id_lang));
		foreach ($states AS $state)
			$statesArray[$state['id_order_state']] = $state['name'];
		
 		$this->fieldsDisplay = array(
		'id_order' => array('title' => $this->l('ID'), 'align' => 'center', 'width' => 25),
		'customer' => array('title' => $this->l('Customer'), 'width' => 140, 'filter_key' => 'c!name'),
		'total_discounts' => array('title' => $this->l('Discounts'), 'width' => 25, 'align' => 'right', 'price' => true),
		'total_shipping' => array('title' => $this->l('Shipping'), 'width' => 25, 'align' => 'right', 'price' => true),
		'total_paid' => array('title' => $this->l('Total'), 'width' => 45, 'align' => 'right', 'prefix' => '<b>', 'suffix' => '</b>', 'price' => true),
		'payment' => array('title' => $this->l('Payment'), 'width' => 100),
		'osname' => array('title' => $this->l('Status'), 'type' => 'select', 'select' => $statesArray, 'filter_key' => 'os!id_order_state'),
		'date_add' => array('title' => $this->l('Date'), 'width' => 40, 'type' => 'date'));
	
		parent::__construct();
	}
	
	/**
	  * @global object $cookie Employee cookie necessary to keep trace of his/her actions
	  */
	public function postProcess()
	{
		global $currentIndex, $cookie;
	
		/* Change order state, add a new entry in order history and send an e-mail to the customer if needed */
		if (isset($_POST['submitState']) AND ($id_order = intval(Tools::getValue('id_order'))) AND Validate::isLoadedObject($order = new Order($id_order)) AND
			(($id_order_state = intval(Tools::getValue('id_order_state'))) != $order->getCurrentState()))
		{
			$history = new OrderHistory();
			$history->id_order = $id_order;
			$history->id_order_state = $id_order_state;
			$history->id_employee = intval($cookie->id_employee);
			if ($history->add())
				Tools::redirectAdmin($currentIndex.'&id_order='.$id_order.'&vieworder');
			$this->_errors[] = Tools::displayError('an error occured while changing state or mail couldn\'t have been sent to the customer');
		}
		
		/* Add a new message for the current order and send an e-mail to the customer if needed */
		elseif (($productName = urldecode(Tools::getValue('deleteProduct'))) AND Validate::isLoadedObject($order = new Order(intval(Tools::getValue('id_order')))))
		{
			if ($order->deleteProduct($productName))
				Tools::redirectLink($currentIndex.'&conf=1');
			else
				die ('kikoo');
		}
		
		/* Add a new message for the current order and send an e-mail to the customer if needed */
		elseif (isset($_POST['submitMessage']))
		{
			if (!($id_order = intval(Tools::getValue('id_order'))) OR !($id_customer = intval(Tools::getValue('id_customer'))))
				$this->_errors[] = Tools::displayError('an error occured before sending message');
			elseif (!Tools::getValue('message'))
				$this->_errors[] = Tools::displayError('message can\'t be empty');
			else
			{
				/* Get message rules and and check fields validity */
				$rules = call_user_func(array('Message', 'getValidationRules'), 'Message');
				foreach ($rules['required'] AS $field)
					if (($value = Tools::getValue($field)) == false AND (string)$value != '0')
						if (!Tools::getValue('id_'.$this->table) OR $field != 'passwd')
							$this->_errors[] = Tools::displayError('field').' <b>'.$field.'</b> '.Tools::displayError('is required');	
				foreach ($rules['size'] AS $field => $maxLength)
					if (Tools::getValue($field) AND strlen(Tools::getValue($field)) > $maxLength)
						$this->_errors[] = Tools::displayError('field').' <b>'.$field.'</b> '.Tools::displayError('is too long').' ('.$maxLength.' '.Tools::displayError('chars max').')';
				foreach ($rules['validate'] AS $field => $function)
					if (Tools::getValue($field))
						if (!Validate::$function(Tools::getValue($field)))
							$this->_errors[] = Tools::displayError('field').' <b>'.$field.'</b> '.Tools::displayError('is invalid');
				if (!sizeof($this->_errors))
				{
					$message = new Message();
					$message->id_employee = intval($cookie->id_employee);
					$message->message = htmlentities(Tools::getValue('message'));
					$message->id_order = $id_order;
					$message->private = Tools::getValue('visibility');
					if (!$message->add())
						$this->_errors[] = Tools::displayError('an error occured while sending message');
					elseif ($message->private)
						Tools::redirectAdmin($currentIndex.'&id_order='.$id_order.'&vieworder&conf=11');
					elseif (Validate::isLoadedObject($customer = new Customer($id_customer)))
					{
						$order = new Order(intval($message->id_order));
						if (Validate::isLoadedObject($order))
							if (Mail::Send(intval($order->id_lang), 'order_merchant_comment', 'New message about your order'.$message->id_order, array('{genre}' => Gender::getNameById($message->id_customer), '{name}' => $customer->name, '{surname}' => $customer->surname, '{id_order}' => $message->id_order, '{message}' => $message->message), $customer->email, $customer->surname.' '.$customer->name))
								Tools::redirectAdmin($currentIndex.'&id_order='.$id_order.'&vieworder&conf=10');
					}
					$this->_errors[] = Tools::displayError('an error occured while sending mail to the customer');
				}
			}
		}
		else
			parent::postProcess();
	}
	
	public function viewDetails()
	{
		global $currentIndex, $cookie;
		$irow = 0;
		$order = $this->loadObject();
		
		$customer = new Customer($order->id_customer);
		$customerStats = $customer->getStats();
		$addressInvoice = new Address($order->id_address_invoice);
		$addressDelivery = new Address($order->id_address_delivery);
		$carrier = new Carrier($order->id_carrier);
		$history = $order->getHistory($cookie->id_lang);
		$products = $order->getProducts();
		$discounts = $order->getDiscounts();
		$messages = Message::getMessagesByOrderId($order->id);
		$states = OrderState::getOrderStates(intval($cookie->id_lang));
		$currency = new Currency(1);
		$link = new Link();
		
		$row = array_shift($history);
		echo '<h2>'.$customer->surname.' '.$customer->name.' n&deg;'.sprintf('%06d', $order->id).' 
		- <a href="pdf.php?id_order='.$order->id.'&pdf"><img src="../img/admin/pdf.gif" alt="'.$this->l('View invoice').'" /></a> 
		- <a href="javascript:window.print()"><img src="../img/admin/printer.gif" alt="'.$this->l('Print order').'" /></a></h2>';
		if ($order->total_paid != $order->total_paid_real)
			echo '<center><span class="warning" style="font-size: 16px">Warning: '.Tools::displayPrice($order->total_paid_real, $currency).' paid instead of '.Tools::displayPrice($order->total_paid, $currency).' !</span></center><div class="clear"><br /><br /></div>';
		
		/* Display current  state */
		echo '
		<div style="float: left;"><table cellspacing="0" cellpadding="0" class="table" style="width: 429px">
			<tr>
				<th>'.Tools::displayDate($row['date_add'], 1, true).'</th>
				<th><img src="../img/os/'.$row['id_order_state'].'.jpg" /></th>
				<th>'.stripslashes($row['ostate_name']).'</th>
				<th>'.((!empty($row['employee_name'])) ? '('.stripslashes(substr($row['employee_surname'], 0, 1)).'. '.stripslashes($row['employee_name']).')' : '').'</th>
			</tr>';
		/* Display previous  states */
		foreach ($history AS $row)
		{
			echo '
			<tr class="'.($irow++ % 2 ? 'alt_row' : '').'">
				<td>'.Tools::displayDate($row['date_add'], 1, true).'</td>
				<td><img src="../img/os/'.$row['id_order_state'].'.jpg" /></td>
				<td>'.stripslashes($row['ostate_name']).'</td>
				<td>'.((!empty($row['employee_name'])) ? '('.stripslashes(substr($row['employee_surname'], 0, 1)).'. '.stripslashes($row['employee_name']).')' : '').'</td>
			</tr>';
		}
		echo '</table></div>
		<div style="float: left; margin-left: 40px">
			<form action="'.$currentIndex.'&view'.$this->table.'" method="post">
				<select name="id_order_state">';
		foreach ($states AS $state)
			echo '<option value="'.$state['id_order_state'].'"'.(($state['id_order_state'] == $order->getCurrentState()) ? ' selected="selected"' : '').'>'.stripslashes($state['name']).'</option>';
		echo '
				</select>
				<input type="hidden" name="id_order" value="'.$order->id.'" />
				<input type="submit" name="submitState" value="'.$this->l('Change status').'" class="button" />
			</form>
		</div>
		<div class="clear">&nbsp;</div>
		<div style="float: left;">
			<fieldset style="width: 400px">
				<legend><img src="../img/admin/tab-customers.gif" /> '.$this->l('Customer informations').'</legend>
				<span style="font-weight: bold; font-size: 14px;"><a href="?tab=AdminCustomers&id_customer='.$customer->id.'&viewcustomer"> '.$customer->surname.' '.$customer->name.'</a></span><br />
				(<a href="mailto:'.$customer->email.'">'.$customer->email.'</a>)<br /><br />
				Registration: '.Tools::displayDate($customer->date_add, 1, true).'<br />
				'.$this->l('Orders placed:').' <b>'.$customerStats['nb_orders'].'</b><br />
				'.$this->l('Total paid since registration:').' <b>'.Tools::displayPrice($customerStats['total_orders'], $currency).'</b><br />
			</fieldset>';
			if (sizeof($messages))
			{
				echo '<br /><fieldset style="width: 400px"><legend><img src="../img/admin/email.gif" /> '.$this->l('Messages').'</legend>';
				foreach ($messages as $message)
					echo '('.Tools::displayDate($message['date_add'], 1, true).') <b>'.(($message['ename']) ? ($message['esurname'].' '.$message['ename']) : ($message['csurname'].' '.$message['cname'])).'</b>: '.$message['message'].'<br />';
				echo '</fieldset><div class="clear">&nbsp;</div>';
			}
		echo '</div>
		<div style="float: left; margin-left: 40px">
			<fieldset style="width: 400px">
				<legend><img src="../img/admin/details.gif" /> '.$this->l('Order details').'</legend>
				<label>'.$this->l('Payment method:').' </label>
				<div style="margin: 2px 0 1em 190px;">'.$order->payment.'</div>
				<label>'.$this->l('Details:').' </label>
				<div style="margin: 2px 0 1em 190px;">
					<table class="table" cellspacing="0" cellpadding="0">
						<tr><td>'.$this->l('Products').'</td><td align="right">'.Tools::displayPrice($order->total_products, $currency).'</td></tr>
						<tr><td>'.$this->l('Discounts').'</td><td align="right">'.Tools::displayPrice($order->total_discounts, $currency).'</td></tr>
						<tr><td>'.$this->l('Shipping').'</td><td align="right">'.Tools::displayPrice($order->total_shipping, $currency).'</td></tr>
						<tr style="font-size: 20px"><td>'.$this->l('Total').'</td><td align="right">'.Tools::displayPrice($order->total_paid, $currency).($order->total_paid != $order->total_paid_real ? '<br /><font color="red">('.$this->l('Paid:').' '.Tools::displayPrice($order->total_paid_real, $currency).')</font>' : '').'</td></tr>
					</table>
					</div>
				<label>'.$this->l('Carrier:').'</label>
				<div style="margin: 2px 0 1em 190px;">'.((file_exists(_PS_SHIP_IMG_DIR_.$carrier->id.'.jpg')) ? '<img src="'._THEME_SHIP_DIR_.$carrier->id.'.jpg" />' : $carrier->name.'&nbsp;').'</div>
				<label>'.$this->l('Recycled package:').' </label>
				<div style="margin: 2px 0 1em 190px;">'.($order->recyclable ? '<img src="../img/admin/enabled.gif" />' : '<img src="../img/admin/disabled.gif" />').'</div>
			</fieldset>			
		</div>
		<div class="clear">&nbsp;</div>
		<div style="float: left">
			<fieldset style="width: 400px;">
				<legend><img src="../img/admin/delivery.gif" alt="Shipping" />'.$this->l('Shipping').'</legend>
				<div style="float: right"><a href="'.$link->getUrlWith('tab', 'AdminAddresses').'&id_address='.$addressDelivery->id.'&addaddress&realedit=1"><img src="../img/admin/edit.gif" /></a></div>
				'. (!empty($addressDelivery->company) ? $addressDelivery->company.'<br />' : '') .$addressDelivery->surname.' '.$addressDelivery->name.'<br />
				'.$addressDelivery->address1.'<br />'. (!empty($addressDelivery->address2) ? $addressDelivery->address2.'<br />' : '') .'
				'.$addressDelivery->postcode.' '.$addressDelivery->city.'<br />
				'.$addressDelivery->country.'
			</fieldset>
		</div>
		<div style="float: left; margin-left: 40px">
			<fieldset style="width: 400px;">
				<legend><img src="../img/admin/invoice.gif" alt="'.$this->l('Invoice').'" />'.$this->l('Invoice').'</legend>
				<div style="float: right"><a href="'.$link->getUrlWith('tab', 'AdminAddresses').'&id_address='.$addressInvoice->id.'&addaddress&realedit=1"><img src="../img/admin/edit.gif" /></a></div>
				'. (!empty($addressInvoice->company) ? $addressInvoice->company.'<br />' : '') .$addressInvoice->surname.' '.$addressInvoice->name.'<br />
				'.$addressInvoice->address1.'<br />'. (!empty($addressInvoice->address2) ? $addressInvoice->address2.'<br />' : '') .'
				'.$addressInvoice->postcode.' '.$addressInvoice->city.'<br />
				'.$addressInvoice->country.'
			</fieldset>
		</div>
		<div class="clear">&nbsp;</div>
		<table style="width: 898px" cellspacing="0" cellpadding="0" class="table">
			<tr><th>'.$this->l('Product name').'</th><th>&nbsp;</th><th style="width: 60px">'.$this->l('Unit price').'</th><th style="width: 20px">'.$this->l('Quantity').'</th><th style="width: 60px">'.$this->l('Total price').'</th></tr>';
		/* prodcuts */
		foreach ($products as $product)
			echo '
			<tr>
				<td style="padding: 6px">'.$product['product_name'].'</td>
				<td><a href="'.$currentIndex.'&id_order='.intval($order->id).'&deleteProduct='.urlencode($product['product_name']).'" onclick="return confirm(\''.addslashes($this->l('Delete').' '.$product['product_name']).'\');"><img src="../img/admin/delete.gif" /></a></td>
				<td align="right">'.Tools::displayPrice($product['product_price'], $currency).'</td>
				<td align="right">'.$product['product_quantity'].'</td>
				<td align="right">'.Tools::displayPrice($product['product_price_wt'] * $product['product_quantity'], $currency).'</td>
			</tr>';
		echo '</table><div class="clear">&nbsp;</div>';
		if (sizeof($discounts))
		{
			echo '<table cellspacing="0" cellpadding="0" class="table"><tr><th>'.$this->l('Discount name').'</th><th>'.$this->l('Value').'</th></tr>';
			foreach ($discounts as $discount)
				echo '<tr><td>'.$discount['name'].'</td><td align="right">-'.Tools::displayPrice($discount['value'], $currency).'</td></tr>';
			echo '</table><div class="clear">&nbsp;</div>';
		}
		echo '	
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post" onsubmit="if (getE(\'visibility\').checked == true) return confirm(\''.$this->l('Do you want to send this message to the customer?').'\');">
			<fieldset style="width: 400px;">
				<legend style="cursor: pointer;" onclick="openCloseLayer(\'message\');openCloseLayer(\'message_m\');"><img src="../img/admin/email_edit.gif" /> '.$this->l('New message').'</legend>
				<div id="message_m" style="display: '.(Tools::getValue('message') ? 'none' : 'block').'">
					<a href="javascript:openCloseLayer(\'message\');openCloseLayer(\'message_m\');">'.$this->l('Click here to add a comment or send a message to the customer').'</a>
				</div>
				<div id="message" style="display: '.(Tools::getValue('message') ? 'block' : 'none').'">
					<b>'.$this->l('Display to consumer?').'</b>
					<input type="radio" name="visibility" id="visibility" value="0" /> '.$this->l('Yes').'
					<input type="radio" name="visibility" value="1" checked="checked" /> '.$this->l('No').'<br /><br />
					<textarea name="message" cols="60" rows="8">'.Tools::getValue('message').'</textarea><br /><br />
					<input type="hidden" name="id_order" value="'.$order->id.'" />
					<input type="hidden" name="id_customer" value="'.$order->id_customer.'" />
					<input type="submit" class="button" name="submitMessage" value="'.$this->l('Send').'" />
				</div>
			</fieldset>
		</form>
		<br /><br /><a href="'.$currentIndex.'"><img src="../img/admin/arrow.gif" /> '.$this->l('Back to list').'</a><br />';
	}
	
	public function display()
	{
		global $cookie;
		
		if (isset($_GET['view'.$this->table]))
			$this->viewDetails();
		else
		{
			$this->getList(intval($cookie->id_lang), 'date_add', 'DESC');
			$this->displayList();
		}
	}
}

?>