<?php

/**
  * Orders states tab for admin panel, AdminOrdersStates.php
  * @category admin
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */
  
class AdminOrdersStates extends AdminTab
{
	public function __construct()
	{
	 	$this->table = 'order_state';
	 	$this->className = 'OrderState';
	 	$this->lang = true;
	 	$this->edit = true;
 
		$this->fieldImageSettings = array('name' => 'icon', 'dir' => 'os');
			
		$this->fieldsDisplay = array(
		'id_order_state' => array('title' => $this->l('ID'), 'align' => 'center', 'width' => 25),
		'name' => array('title' => $this->l('Name'), 'width' => 130),
		'logo' => array('title' => $this->l('Icon'), 'align' => 'center', 'image' => 'os', 'orderby' => false, 'search' => false),
		'send_email' => array('title' => $this->l('E-mail customer'), 'align' => 'center', 'icon' => array('1' => 'enabled.gif', '0' => 'disabled.gif'), 'type' => 'bool'),
		'invoice' => array('title' => $this->l('Invoice'), 'align' => 'center', 'icon' => array('1' => 'enabled.gif', '0' => 'disabled.gif'), 'type' => 'bool'),
		'template' => array('title' => $this->l('E-mail template'), 'width' => 100));
	
		parent::__construct();
	}
	
	public function postProcess()
	{
		if (Tools::isSubmit('submitAdd'.$this->table))
		{
			$_POST['send_email'] = Tools::getValue('send_email');
			$_POST['invoice'] = Tools::getValue('invoice');
		}
		parent::postProcess();
	}
	
	private function getTemplates($iso_code)
	{
		$array = array();
		$templates = scandir(dirname(__FILE__).'/../../mails/'.$iso_code);
		foreach ($templates AS $template)
			if (!strncmp(strrev($template), 'lmth.', 5))
				$array[] = substr($template, 0, -5);
		return $array;
	}
	
	public function displayForm()
	{
		global $currentIndex;
		
		$obj = $this->loadObject(true);
		$defaultLanguage = intval(Configuration::get('PS_LANG_DEFAULT'));
		$languages = Language::getLanguages();

		echo '
		<script type="text/javascript">
			id_language = Number('.$defaultLanguage.');
		</script>
		<form action="'.$currentIndex.'&submitAdd'.$this->table.'=1" method="post" enctype="multipart/form-data">
		'.($obj->id ? '<input type="hidden" name="id_'.$this->table.'" value="'.$obj->id.'" />' : '').'
			<fieldset class="width3"><legend><img src="../img/admin/time.gif" />'.$this->l('Orders States').'</legend>
				<label>'.$this->l('Name:').' </label>
				<div class="margin-form">';

				foreach ($languages as $language)
					echo '
					<div id="name_'.$language['id_lang'].'" style="display: '.($language['id_lang'] == $defaultLanguage ? 'block' : 'none').'; float: left;">
						<input size="40" type="text" name="name_'.$language['id_lang'].'" value="'.$this->getFieldValue($obj, 'name', intval($language['id_lang'])).'" style="width: 150px;" /><sup> *</sup>
						<span class="hint" name="help_box">'.$this->l('Forbidden characters: numbers and').' !<>,;?=+()@#"{}_$%:<span class="hint-pointer">&nbsp;</span></span>
						</div>';							
				displayFlags($languages, $defaultLanguage, 'nametemplate', 'name');

		echo '		<p style="clear: both">'.$this->l('Order state, eg. Pending').'</p>
				</div>
				<label>'.$this->l('Icon:').' </label>
				<div class="margin-form">
					<input type="file" name="icon" />
					<p>'.$this->l('Upload icon from your computer').' (.gif, .jpg, .jpeg or .png)</p>
				</div>
				<label>'.$this->l('Color:').' </label>
				<div class="margin-form">
					<input type="text" name="color" value="'.$this->getFieldValue($obj, 'color').'" />
					<p>'.$this->l('The state will be highlighted in this color (HTML colors)').'</p>
				</div>
				<div class="margin-form">
					<p><input type="checkbox" name="invoice"'.(($this->getFieldValue($obj, 'invoice') == 1) ? ' checked="checked"' : '').' value="1" /> '.$this->l('Allow to view and download PDF invoice').'</p>
				</div>
				<div class="margin-form">
					<p><input type="checkbox" name="send_email" onclick="javascript:openCloseLayer(\'tpl\');"'.
					(($this->getFieldValue($obj, 'send_email')) ? 'checked="checked"' : '').' value="1" /> '.$this->l('Send e-mail to customer when order gets to this state').'</p>
				</div>				
				<div id="tpl" style="display: '.($this->getFieldValue($obj, 'send_email') ? 'block' : 'none').';">
					<label>'.$this->l('').'Template:</label>
					<div class="margin-form">';
			foreach ($languages as $language)
			{
				$templates = $this->getTemplates($language['iso_code']);
				echo '	<div id="template_'.$language['id_lang'].'" style="display: '.($language['id_lang'] == $defaultLanguage ? 'block' : 'none').'; float: left;">
							<select	name="template_'.$language['id_lang'].'">';
				foreach ($templates AS $template)
					echo '		<option value="'.$template.'" '.(($this->getFieldValue($obj, 'template', intval($language['id_lang'])) == $template) ? 'selected="selected"' : '').'>'.$template.'</option>';
				echo '		</select>
							<span class="hint" name="help_box">'.$this->l('Only letters, number and -_ are allowed').'<span class="hint-pointer">&nbsp;</span></span>
						</div>';
			}
			displayFlags($languages, $defaultLanguage, 'nametemplate', 'template');
			echo '
						<p style="clear: both">'.$this->l('Email template, for both .html and .txt').'</p>
					</div>
				</div>
				<div class="margin-form">
					<input type="submit" value="'.$this->l('   Save   ').'" name="submitAdd'.$this->table.'" class="button" />
				</div>
				<div class="small"><sup>*</sup> '.$this->l('required fields').'</div>
			</fieldset>
		</form>';
	}
}

?>