<?php

/**
  * Payment modules class, PaymentModule.php
  * Payment modules management and abstraction
  * @category classes
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */

include_once(dirname(__FILE__).'/../config/config.inc.php');

abstract class PaymentModule extends Module
{
 	/**
	* Validate an order in database
	* Function called from a payment module
	*
	* @param integer $id_cart Value
	* @param integer $id_order_state Value
	* @param float $amountPaid Amount really paid by customer
	* @param string $paymentMethod Payment method (eg. 'Credit cart')
	* @param string $message Message to attach to order
	*/
    function validateOrder($id_cart, $id_order_state, $amountPaid, $paymentMethod = 'Unknown', $message = NULL)
    {
        $cart = new Cart(intval($id_cart));
        
        /* Does order already exists ? */
        if ($cart->id AND $cart->OrderExists() == 0)
        {
         	/* Copying data from cart */
         	$order = new Order();
            $order->id_carrier = $cart->id_carrier;
            $order->id_customer = $cart->id_customer;
            $order->id_address_invoice = $cart->id_address_invoice;
            $order->id_address_delivery = $cart->id_address_delivery;
            $order->id_currency = $cart->id_currency;
            $order->id_lang = $cart->id_lang;
            $order->id_cart = $cart->id;
            $order->payment = $paymentMethod;
            $order->total_paid_real = floatval($amountPaid);
            $order->recyclable = $cart->recyclable;
            
            $currency = new Currency($order->id_currency);
            $order->total_products = number_format($cart->getOrderTotal(false, 1), 2, '.', '');
            $order->total_discounts = number_format(abs($cart->getOrderTotal(true, 2)), 2, '.', '');
            $order->total_shipping = number_format($cart->getOrderShippingCost(), 2, '.', '');
            $order->total_paid = number_format($cart->getOrderTotal(true, 3), 2, '.', '');
            
            /* Amount paid by customer is not the right one -> Status = payment error */
            if ($order->total_paid != number_format($amountPaid, 2, '.', ''))
            	$id_order_state = 7;

			/* Creating order */
            $result = $order->add();

			/* Next ! */
            if ($result AND isset($order->id))
            {
             	/* Set order state in order history */
                $history = new OrderHistory();
				$history->id_order = $order->id;
				$history->id_order_state = intval($id_order_state);
				$history->add();
				
				/* Optional message to attach to this order */
				if (isset($message) AND !empty($message))
				{
					$msg = new Message();
					$msg->message = $message;
					$msg->id_order = $order->id;
					$msg->id_employee = 1;
					$msg->private = 1;
					$msg->add();
				}
				
				/* Insert products from cart into order_detail table */
                $products = $cart->getProducts();
                $productsList = '';
                $db = Db::getInstance();
                $query = 'INSERT INTO `'._DB_PREFIX_.'order_detail` (`id_order`, `product_name`, `product_quantity`, `product_price`, 
				`product_reference`, `product_weight`, `tax_name`, `tax_rate`) VALUES ';
				foreach ($products AS $product)
                {				
					if ($id_order_state != 5 AND $id_order_state != 7)
					{
						if (!Product::updateQuantity($product) && $id_order_state != 8)
						{
							$id_order_state = 8;
							$history = new OrderHistory();
							$history->id_order = $order->id;
							$history->id_order_state = 8;
							$history->add();
						}
						Hook::updateQuantity($product, $order);
					}

					$price = Product::getPriceStatic(intval($product['id_product']), false, ($product['id_product_attribute'] ? intval($product['id_product_attribute']) : NULL), 3);

					$query .= '('.intval($order->id).', \''.pSQL($product['name'].($product['attributes'] != NULL ? ' - '.$product['attributes'] : '')).'\', 
					'.intval($product['quantity']).', '.$price.', \''.pSQL($product['reference']).'\', 
					'.floatval($product['weight']).', \''.pSQL($product['tax']).'\', '.floatval($product['rate']).'),';

                    $productsList .=
                    '<tr>
                        <td align="center" style="height: 25px; border-left: 1px solid #000000;">'.intval($product['quantity']).'</td>
                        <td style=" border-left: 1px solid #000000; border-right: 1px solid #000000;">'.$product['name'].(isset($product['attributes_small']) ? ' '.$product['attributes_small'] : '').'</td>
                        <td align="right" style="border-right: 1px solid #000000;">'.Tools::displayPrice($price * ($product['rate'] + 100) / 100, $currency).'</td>
                    </tr>';
                }                
                $query = rtrim($query, ',');
                $result = $db->Execute($query);
                
                /* Insert discounts from cart into order_discount table */
                $discounts = $cart->getDiscounts();
                $discountsList = '';
                foreach ($discounts AS $discount)
                {
                    $objDiscount = new Discount($discount['id_discount']);
                    $value = number_format($objDiscount->getValue(sizeof($discounts), $cart->getOrderTotal(true, 1), $order->total_shipping), 2);
                    $order->addDiscount($objDiscount->id, $objDiscount->name, $value);
					if ($id_order_state != 5 AND $id_order_state != 7)
	                    $objDiscount->quantity = $objDiscount->quantity - 1;
                    $objDiscount->update();
                    
                    $discountsList .=
                    '<tr>
                        <td align="center" style="height: 25px; border-left: 1px solid #000000;">1</td>
                        <td style=" border-left: 1px solid #000000; border-right: 1px solid #000000;">Code de r&eacute;duction : '.$objDiscount->name.'</td>
                        <td align="right" style="border-right: 1px solid #000000;">-'.Tools::displayPrice($value, $currency).'</td>
                    </tr>';
                }
                
                /* Specify order id for message */
				$oldMessage = Message::getMessageByCartId(intval($cart->id));
				if ($oldMessage)
				{
					$message = new Message(intval($oldMessage['id_message']));
					$message->id_order = intval($order->id);
					$message->update();
				}
				
				/* Hook new order */
				$customer = new Customer($order->id_customer);
				Hook::newOrder($cart, $order, $customer, $currency);
				
				/* Send an e-mail to customer */
				if ($id_order_state != 5 AND $id_order_state != 7 AND $customer->id)
				{
					$delivery = new Address(intval($order->id_address_invoice));
					$invoice = new Address(intval($order->id_address_delivery));
					$carrier = new Carrier(intval($order->id_carrier));

					$data = array(
					'{surname}' => $customer->surname,
					'{name}' => $customer->name,
					'{email}' => $customer->email,				
					'{delivery_surname}' => $delivery->surname,
					'{delivery_name}' => $delivery->name,
					'{delivery_address1}' => $delivery->address1,
					'{delivery_address2}' => $delivery->address2,
					'{delivery_city}' => $delivery->city,
					'{delivery_postal_code}' => $delivery->postcode,
					'{delivery_country}' => $delivery->country,
					'{invoice_surname}' => $invoice->surname,
					'{invoice_name}' => $invoice->name,
					'{invoice_address2}' => $invoice->address2,
					'{invoice_address1}' => $invoice->address1,
					'{invoice_city}' => $invoice->city,
					'{invoice_postal_code}' => $invoice->postcode,
					'{invoice_country}' => $invoice->country,
					'{order_name}' => sprintf("%06d", intval($order->id)),
					'{date}' => Tools::displayDate(date('Y-m-d h:i:s'), intval($order->id_lang), 1),
					'{carrier}' => $carrier->name,
					'{payment}' => $order->payment,
					'{products}' => $productsList,
					'{discounts}' => $discountsList,
					'{total_paid}' => Tools::displayPrice($order->total_paid, $currency),
					'{total_products}' => Tools::displayPrice(($order->total_paid - $order->total_shipping + $order->total_discounts), $currency),
					'{total_discounts}' => Tools::displayPrice($order->total_discounts, $currency),
					'{total_shipping}' => Tools::displayPrice($order->total_shipping, $currency));
					
					/* Join PDF invoice */
					if ($id_order_state != 1)
					{
						$fileAttachment['content'] = PDF::invoice($order, 'S');
						$fileAttachment['name'] = sprintf("FA%06d", intval($order->id));
						$fileAttachment['mime'] = 'application/pdf';
					}
					else
					 $fileAttachment = NULL;
					
					if (Validate::isEmail($customer->email))
						Mail::Send(intval($order->id_lang), 'order_conf', 'Order confirmation', $data, 
						$customer->email, $customer->surname.' '.$customer->name, NULL, NULL, $fileAttachment);
				}
			}
			else
				die('Order creation failed');
        }
        else
          die('Cart products unreachable');
    }
}

?>