CREATE TABLE image_type (
  id_image_type INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(16) NOT NULL,
  width INTEGER UNSIGNED NOT NULL,
  height INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(id_image_type),
  INDEX image_type_name(name)
);

CREATE TABLE hook (
  id_hook INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(64) NOT NULL,
  title VARCHAR(64) NOT NULL,
  description TEXT NULL,
  position BOOL NOT NULL DEFAULT 1,
  PRIMARY KEY(id_hook),
  INDEX hook_name(name)
);

CREATE TABLE manufacturer (
  id_manufacturer INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(64) NOT NULL,
  date_add DATETIME NOT NULL,
  date_upd DATETIME NOT NULL,
  PRIMARY KEY(id_manufacturer)
);

CREATE TABLE lang (
  id_lang INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(32) NOT NULL,
  active TINYINT UNSIGNED NOT NULL DEFAULT 0,
  iso_code CHAR(2) NOT NULL,
  PRIMARY KEY(id_lang),
  INDEX lang_iso_code(iso_code)
);

CREATE TABLE currency (
  id_currency INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(32) NOT NULL,
  sign VARCHAR(8) NOT NULL,
  format TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  conversion_rate DECIMAL(10,2) NOT NULL,
  deleted TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(id_currency)
);

CREATE TABLE contact (
  id_contact INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  email VARCHAR(128) NOT NULL,
  position TINYINT(2) UNSIGNED NOT NULL,
  PRIMARY KEY(id_contact)
);

CREATE TABLE gender (
  id_gender INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  iso_code TINYINT(3) UNSIGNED NOT NULL,
  name VARCHAR(16) NOT NULL,
  PRIMARY KEY(id_gender)
);

CREATE TABLE discount_type (
  id_discount_type INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  PRIMARY KEY(id_discount_type)
);

CREATE TABLE module (
  id_module INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(64) NOT NULL,
  active INTEGER UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(id_module)
);

CREATE TABLE tab (
  id_tab INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_parent INTEGER NOT NULL,
  class_name VARCHAR(64) NOT NULL,
  icon VARCHAR(64) NOT NULL,
  PRIMARY KEY(id_tab)
);

CREATE TABLE search (
  id_search INTEGER UNSIGNED NOT NULL,
  keyword VARCHAR(64) NOT NULL,
  results INTEGER UNSIGNED NOT NULL DEFAULT 0,
  date DATETIME NOT NULL,
  PRIMARY KEY(id_search),
  INDEX search_keyword(keyword)
);

CREATE TABLE zone (
  id_zone INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(64) NOT NULL,
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  enabled TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(id_zone)
);

CREATE TABLE tax (
  id_tax INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  rate FLOAT NOT NULL,
  PRIMARY KEY(id_tax)
);

CREATE TABLE profile (
  id_profile INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  PRIMARY KEY(id_profile)
);

CREATE TABLE order_state (
  id_order_state INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  invoice TINYINT(1) UNSIGNED NULL DEFAULT 0,
  send_email TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  color VARCHAR(32) NULL,
  PRIMARY KEY(id_order_state)
);

CREATE TABLE range_weight (
  id_range_weight INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  delimiter1 FLOAT NOT NULL DEFAULT 0,
  delimiter2 FLOAT NOT NULL DEFAULT 0,
  PRIMARY KEY(id_range_weight),
  INDEX range_weight_index(delimiter1, delimiter2)
);

CREATE TABLE range_price (
  id_range_price INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  delimiter1 FLOAT NOT NULL DEFAULT 0,
  delimiter2 FLOAT NOT NULL DEFAULT 0,
  PRIMARY KEY(id_range_price),
  INDEX range_price_index(delimiter1, delimiter2)
);

CREATE TABLE attribute_group (
  id_attribute_group INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  PRIMARY KEY(id_attribute_group)
);

CREATE TABLE accessory (
  id_accessory INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_product_1 INTEGER UNSIGNED NOT NULL,
  id_product_2 INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(id_accessory),
  INDEX accessory_product(id_product_1)
);

CREATE TABLE configuration (
  id_configuration INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(32) NOT NULL,
  value TEXT NULL,
  date_add DATETIME NOT NULL,
  date_upd DATETIME NOT NULL,
  PRIMARY KEY(id_configuration),
  INDEX configuration_name(name)
);

CREATE TABLE carrier (
  id_carrier INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(64) NOT NULL,
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  deleted TINYINT UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(id_carrier)
);

CREATE TABLE category (
  id_category INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_parent INTEGER UNSIGNED NOT NULL,
  level_depth TINYINT(3) UNSIGNED NOT NULL DEFAULT 0,
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  date_add DATETIME NOT NULL,
  date_upd DATETIME NOT NULL,
  PRIMARY KEY(id_category),
  INDEX category_parent(id_parent)
);

CREATE TABLE attribute (
  id_attribute INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_attribute_group INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(id_attribute),
  INDEX attribute_group(id_attribute_group)
);

CREATE TABLE employee (
  id_employee INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(32) NOT NULL,
  surname VARCHAR(32) NOT NULL,
  email VARCHAR(128) NOT NULL,
  passwd VARCHAR(32) NOT NULL,
  is_admin TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  id_profile INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(id_employee),
  INDEX employee_login(email, passwd),
  INDEX employee_profile(id_profile)
);

CREATE TABLE country (
  id_country INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_zone INTEGER UNSIGNED NOT NULL,
  iso_code VARCHAR(3) NOT NULL,
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(id_country),
  INDEX country_iso_code(iso_code),
  INDEX country_zone(id_zone)
);

CREATE TABLE tag (
  id_tag INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_lang INTEGER UNSIGNED NOT NULL,
  name VARCHAR(32) NOT NULL,
  PRIMARY KEY(id_tag),
  INDEX tag_name(name)
);

CREATE TABLE customer (
  id_customer INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_gender INTEGER UNSIGNED NOT NULL,
  email VARCHAR(128) NOT NULL,
  passwd VARCHAR(32) NOT NULL,
  birthday DATE NULL,
  name VARCHAR(32) NOT NULL,
  newsletter TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  optin TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  surname VARCHAR(32) NOT NULL,
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  date_add DATETIME NOT NULL,
  date_upd DATETIME NOT NULL,
  PRIMARY KEY(id_customer),
  INDEX customer_login(email, passwd)
);

CREATE TABLE order_state_lang (
  id_order_state INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  name VARCHAR(64) NOT NULL,
  template VARCHAR(64) NOT NULL,
  UNIQUE INDEX order_state_lang_index(id_order_state, id_lang)
);

CREATE TABLE product (
  id_product INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_manufacturer INTEGER UNSIGNED NULL,
  id_tax INTEGER UNSIGNED NOT NULL,
  bargain TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  ean13 VARCHAR(13) NULL,
  ecotax DECIMAL(10,2) NOT NULL DEFAULT 0,
  quantity INTEGER UNSIGNED NOT NULL DEFAULT 0,
  price DECIMAL(10,4) NOT NULL DEFAULT 0,
  reduction_price DECIMAL(10,2) NULL,
  reduction_percent FLOAT NULL,
  reference VARCHAR(32) NULL,
  weight FLOAT NOT NULL DEFAULT 0,
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  date_add DATETIME NOT NULL,
  date_upd DATETIME NOT NULL,
  PRIMARY KEY(id_product)
);

CREATE TABLE tab_lang (
  id_lang INTEGER UNSIGNED NOT NULL,
  id_tab INTEGER UNSIGNED NOT NULL,
  name VARCHAR(32) NULL,
  INDEX tab_lang(id_lang, id_tab)
);

CREATE TABLE address (
  id_address INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_country INTEGER UNSIGNED NOT NULL,
  id_customer INTEGER UNSIGNED NOT NULL,
  alias VARCHAR(32) NOT NULL,
  company VARCHAR(32) NULL,
  name VARCHAR(32) NOT NULL,
  surname VARCHAR(32) NOT NULL,
  address1 VARCHAR(128) NOT NULL,
  address2 VARCHAR(128) NULL,
  postcode VARCHAR(12) NULL,
  city VARCHAR(64) NOT NULL,
  other TEXT NULL,
  phone VARCHAR(16) NULL,
  phone_mobile VARCHAR(16) NULL,
  date_add DATETIME NOT NULL,
  date_upd DATETIME NOT NULL,
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT 1,
  deleted TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(id_address),
  INDEX address_customer(id_customer)
);

CREATE TABLE access (
  id_access INTEGER NOT NULL AUTO_INCREMENT,
  id_profile INTEGER UNSIGNED NOT NULL,
  id_tab INTEGER UNSIGNED NOT NULL,
  view INTEGER NOT NULL,
  `add` INTEGER NOT NULL,
  edit INTEGER NOT NULL,
  `delete` INTEGER NOT NULL,
  PRIMARY KEY(id_access),
  INDEX access_profile(id_profile),
  INDEX access_tab(id_tab)
);

CREATE TABLE tax_lang (
  id_tax INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  name VARCHAR(32) NOT NULL,
  UNIQUE INDEX tax_lang_index(id_tax, id_lang)
);

CREATE TABLE attribute_lang (
  id_attribute INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  name VARCHAR(128) NOT NULL,
  UNIQUE INDEX attribute_lang_index(id_attribute, id_lang)
);

CREATE TABLE product_tag (
  id_product INTEGER UNSIGNED NOT NULL,
  id_tag INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(id_product, id_tag)
);

CREATE TABLE attribute_group_lang (
  id_attribute_group INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  name VARCHAR(128) NOT NULL,
  public_name VARCHAR(64) NOT NULL,
  INDEX attribute_group_lang_index(id_attribute_group, id_lang)
);

CREATE TABLE profile_lang (
  id_lang INTEGER UNSIGNED NOT NULL,
  id_profile INTEGER UNSIGNED NOT NULL,
  name VARCHAR(128) NOT NULL,
  INDEX profile_lang_index(id_lang, id_profile)
);

CREATE TABLE category_product (
  id_category INTEGER UNSIGNED NOT NULL,
  id_product INTEGER UNSIGNED NOT NULL,
  INDEX category_product_index(id_category, id_product)
);

CREATE TABLE category_lang (
  id_category INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  name VARCHAR(128) NOT NULL,
  description TEXT NULL,
  link_rewrite  VARCHAR(128) NOT NULL,
  meta_title VARCHAR(128) NULL,
  meta_keywords VARCHAR(128) NULL,
  meta_description VARCHAR(128) NULL,
  UNIQUE INDEX category_lang_index(id_category, id_lang)
);

CREATE TABLE discount_type_lang (
  id_discount_type INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  name VARCHAR(32) NOT NULL,
  INDEX discount_type_lang_index(id_discount_type, id_lang)
);

CREATE TABLE contact_lang (
  id_contact INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  name VARCHAR(32) NOT NULL,
  description TEXT NULL,
  UNIQUE INDEX contact_lang_index(id_contact, id_lang)
);

CREATE TABLE configuration_lang (
  id_configuration INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  value TEXT NULL,
  date_upd DATETIME NULL,
  INDEX configuration_lang_index(id_configuration, id_lang)
);

CREATE TABLE discount (
  id_discount INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_discount_type INTEGER UNSIGNED NOT NULL,
  id_customer INTEGER UNSIGNED NOT NULL,
  name VARCHAR(32) NOT NULL,
  value DECIMAL(10,2) NOT NULL DEFAULT 0,
  quantity INTEGER UNSIGNED NOT NULL DEFAULT 0,
  cumulable TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  cumulable_reduction TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  date_from DATETIME NOT NULL,
  date_to DATETIME NOT NULL,
  minimal DECIMAL(10,2) NULL,
  everybody TINYINT(1) UNSIGNED NOT NULL DEFAULT 1,
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(id_discount),
  INDEX discount_name(name),
  INDEX discount_customer(id_customer)
);

CREATE TABLE country_lang (
  id_country INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  name VARCHAR(64) NOT NULL,
  UNIQUE INDEX country_lang_index(id_country, id_lang)
);

CREATE TABLE hook_module (
  id_module INTEGER UNSIGNED NOT NULL,
  id_hook INTEGER UNSIGNED NOT NULL,
  position TINYINT(2) UNSIGNED NOT NULL,
  INDEX hook_module_index(id_module, id_hook)
);

CREATE TABLE carrier_lang (
  id_carrier INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  delay VARCHAR(128) NULL,
  UNIQUE INDEX shipper_lang_index(id_lang, id_carrier)
);

CREATE TABLE delivery (
  id_delivery INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_carrier INTEGER UNSIGNED NOT NULL,
  id_range_price INTEGER UNSIGNED NULL,
  id_range_weight INTEGER UNSIGNED NULL,
  id_zone INTEGER UNSIGNED NOT NULL,
  price DECIMAL(10,2) NOT NULL,
  PRIMARY KEY(id_delivery)
);

CREATE TABLE cart (
  id_cart INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_carrier INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  id_address_delivery INTEGER UNSIGNED NOT NULL,
  id_address_invoice INTEGER UNSIGNED NOT NULL,
  id_currency INTEGER UNSIGNED NOT NULL,
  id_customer INTEGER UNSIGNED NOT NULL,
  recyclable TINYINT(1) UNSIGNED NOT NULL DEFAULT 1,
  date_add DATETIME NOT NULL,
  date_upd DATETIME NOT NULL,
  PRIMARY KEY(id_cart),
  INDEX cart_customer(id_customer)
);

CREATE TABLE orders (
  id_order INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_carrier INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  id_customer INTEGER UNSIGNED NOT NULL,
  id_cart INTEGER UNSIGNED NOT NULL,
  id_currency INTEGER UNSIGNED NOT NULL,
  id_address_delivery INTEGER UNSIGNED NOT NULL,
  id_address_invoice INTEGER UNSIGNED NOT NULL,
  payment VARCHAR(64) NOT NULL,
  recyclable TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  total_discounts DECIMAL(10,2) NOT NULL DEFAULT 0,
  total_paid DECIMAL(10,2) NOT NULL DEFAULT 0,
  total_paid_real DECIMAL(10,2) NOT NULL DEFAULT 0,
  total_products DECIMAL(10,2) NOT NULL DEFAULT 0,
  total_shipping DECIMAL(10,2) NOT NULL DEFAULT 0,
  date_add DATETIME NOT NULL,
  date_upd DATETIME NOT NULL,
  PRIMARY KEY(id_order),
  INDEX orders_customer(id_customer)
);

CREATE TABLE image (
  id_image INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_product INTEGER UNSIGNED NOT NULL,
  position TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  cover TINYINT(1) UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(id_image),
  INDEX image_product(id_product)
);

CREATE TABLE order_detail (
  id_order_detail INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_order INTEGER UNSIGNED NOT NULL,
  product_name VARCHAR(128) NOT NULL,
  product_quantity INTEGER UNSIGNED NOT NULL DEFAULT 0,
  product_price DECIMAL(10,2) NOT NULL DEFAULT 0,
  product_reference VARCHAR(32) NULL,
  product_weight FLOAT NOT NULL,
  tax_name VARCHAR(16) NOT NULL,
  tax_rate DECIMAL(10,2) NOT NULL DEFAULT 0,
  PRIMARY KEY(id_order_detail),
  INDEX order_detail_order(id_order)
);

CREATE TABLE order_discount (
  id_order_discount INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_order INTEGER UNSIGNED NOT NULL,
  name VARCHAR(32) NOT NULL,
  value DECIMAL(10,2) NOT NULL DEFAULT 0,
  PRIMARY KEY(id_order_discount),
  INDEX order_discount_order(id_order)
);

CREATE TABLE connections (
  id_connections INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_customer INTEGER UNSIGNED NOT NULL,
  ip_address VARCHAR(16) NOT NULL,
  date DATETIME NOT NULL,
  PRIMARY KEY(id_connections)
);

CREATE TABLE product_lang (
  id_product INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  description TEXT NULL,
  description_short TEXT NULL,
  link_rewrite VARCHAR(128) NOT NULL,
  meta_description VARCHAR(255) NULL,
  meta_keywords VARCHAR(255) NULL,
  meta_title VARCHAR(128) NULL,
  name VARCHAR(128) NOT NULL,
  UNIQUE INDEX product_lang_index(id_product, id_lang)
);

CREATE TABLE product_attribute (
  id_product_attribute INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_image INTEGER UNSIGNED NULL,
  id_product INTEGER UNSIGNED NOT NULL,
  reference VARCHAR(32) NULL,
  ean13 VARCHAR(13) NULL,
  price DECIMAL(10,2) NOT NULL DEFAULT 0,
  ecotax DECIMAL(10,2) NOT NULL DEFAULT 0,
  quantity INTEGER UNSIGNED NOT NULL DEFAULT 0,
  weight FLOAT NOT NULL DEFAULT 0,
  PRIMARY KEY(id_product_attribute),
  INDEX product_attribute_product(id_product)
);

CREATE TABLE discount_lang (
  id_discount INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  description TEXT NULL,
  INDEX discount_lang_index(id_discount, id_lang)
);

CREATE TABLE cart_discount (
  id_cart INTEGER UNSIGNED NOT NULL,
  id_discount INTEGER UNSIGNED NOT NULL,
  INDEX cart_discount_index(id_cart, id_discount)
);

CREATE TABLE image_lang (
  id_image INTEGER UNSIGNED NOT NULL,
  id_lang INTEGER UNSIGNED NOT NULL,
  legend VARCHAR(64) NULL,
  UNIQUE INDEX image_lang_index(id_image, id_lang)
);

CREATE TABLE order_history (
  id_order_history INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_employee INTEGER UNSIGNED NOT NULL,
  id_order INTEGER UNSIGNED NOT NULL,
  id_order_state INTEGER UNSIGNED NOT NULL,
  date_add DATETIME NOT NULL,
  PRIMARY KEY(id_order_history),
  INDEX order_history_order(id_order)
);

CREATE TABLE cart_product (
  id_cart INTEGER UNSIGNED NOT NULL,
  id_product INTEGER UNSIGNED NOT NULL,
  id_product_attribute INTEGER UNSIGNED NULL,
  quantity INTEGER UNSIGNED NOT NULL DEFAULT 0,
  INDEX cart_product_index(id_cart, id_product)
);

CREATE TABLE message (
  id_message INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  id_cart INTEGER UNSIGNED NULL,
  id_customer INTEGER UNSIGNED NOT NULL,
  id_employee INTEGER UNSIGNED NULL,
  id_order INTEGER UNSIGNED NOT NULL,
  message TEXT NOT NULL,
  private TINYINT(1) UNSIGNED NOT NULL DEFAULT 1,
  date_add DATETIME NOT NULL,
  PRIMARY KEY(id_message),
  INDEX message_order(id_order)
);

CREATE TABLE product_attribute_combinaison (
  id_attribute INTEGER UNSIGNED NOT NULL,
  id_product_attribute INTEGER UNSIGNED NOT NULL,
  INDEX product_attribute_combinaison_index(id_attribute, id_product_attribute)
);
