<?php

class Paypal extends PaymentModule
{
	private	$_html = '';
    private $_postErrors = array();
	
	private $_formAction;
    
	public function __construct()
	{
		$this->name = 'paypal';
        $this->tab = 'Payment';
        $this->version = 1.02;
		
		$this->_translations = array(
			'FR' => array(
				'Accepts payments by Paypal' => 'Syst&egrave;me de paiement s&eacute;curis&eacute; Paypal',
				'Pay with Paypal' => 'Payez avec Paypal',
				'My cart' => 'Mon panier', 
				'Confirmation' => 'Confirmation', 
				'Settings updated' => 'Configuration mise &agrave; jour', 
				'There is' => 'Il y a',  
				'There are' => 'Il y a', 
				'error' => 'erreur',
				'errors' => 'erreurs',
				'Settings' => 'R&eacute;glages', 
				'Paypal business e-mail' => 'E-mail marchand Paypal', 
				'Sandbox mode' => 'Mode Sandbox', 
				'Yes' => 'Oui', 
				'No' => 'Non', 
				'Informations' => 'Informations', 
				'In order to use your paypal payment module, you have to configure your paypal account (sandbox account as well as real one). Log in to paypal then:' => 'Afin d\'utiliser votre module de paiement Paypal, vous devez d\'abord configurer votre compte Paypal (y compris le compte sandbox). Identifiez-vous dans Paypal, puis : ', 
				'In' => 'Dans', 
				'set' => 'r&eacute;glez', 
				'to' => 'sur', 
				'to whatever you choose' => 'sur ce que vous souhaitez',
				'is recommended' => 'est recommand&eacute;', 
				'Be also sure that' => 'Assurez-vous &eacute;galement que', 
				'is set to' => 'est r&eacute;gl&eacute; sur', 
				'Update settings' => 'Mise &agrave; jour des r&eacute;glages'
			)
		);
		
		$this->_formAction = array('https://www.paypal.com/cgi-bin/webscr', 'https://www.sandbox.paypal.com/cgi-bin/webscr');
        parent::__construct();
        
        /* The parent construct is required for translations */
        $this->displayName = $this->l('Paypal');
        $this->description = $this->l('Accepts payments by Paypal');
	}
	
	public function install()
	{
		parent::install();
		Configuration::updateValue('PAYPAL_SANDBOX', 1);
		$this->registerHook('payment');
	}
	
	public function uninstall()
	{
		Configuration::deleteByName('PAYPAL_BUSINESS');
		Configuration::deleteByName('PAYPAL_SANDBOX');
		parent::uninstall();
	}
	
	public function getContent()
	{
		$this->_html = '<h2>Paypal</h2>';
		if (isset($_POST['submitPaypal']))
		{
			if (!isset($_POST['business']) OR empty($_POST['business']))
				$this->_postErrors[] = 'Paypal business e-mail address is required.';
			elseif (!Validate::isEmail($_POST['business']))
				$this->_postErrors[] = 'Paypal business must be an e-mail address.';
			if (!isset($_POST['sandbox']))
				$_POST['sandbox'] = 1;
			if (!sizeof($this->_postErrors))
			{
				Configuration::updateValue('PAYPAL_BUSINESS', $_POST['business']);
				Configuration::updateValue('PAYPAL_SANDBOX', intval($_POST['sandbox']));
				$this->displayConf();
			}
			else
				$this->displayErrors();
		}
		
		$this->displayFormSettings();
		return $this->_html;
	}
	
	public function displayConf()
	{
		$this->_html .= '
		<div class="conf confirm">
			<img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />
			'.$this->l('Settings updated').'
		</div>';
	}
	
	public function displayErrors()
	{
		$nbErrors = sizeof($this->_postErrors);
		$this->_html .= '
		<div class="alert error">
			<h3>'.($nbErrors > 1 ? $this->l('There are') : $this->l('There is')).' '.$nbErrors.' '.($nbErrors > 1 ? $this->l('errors') : $this->l('error')).'</h3>
			<ol>';
		foreach ($this->_postErrors AS $error)
			$this->_html .= '<li>'.$error.'</li>';
		$this->_html .= '
			</ol>
		</div>';
	}
	
	public function displayFormSettings()
	{
		$conf = Configuration::getMultiple(array('PAYPAL_BUSINESS', 'PAYPAL_SANDBOX'));
		$business = array_key_exists('business', $_POST) ? $_POST['business'] : (array_key_exists('PAYPAL_BUSINESS', $conf) ? $conf['PAYPAL_BUSINESS'] : '');
		$sandbox = array_key_exists('sandbox', $_POST) ? $_POST['sandbox'] : (array_key_exists('PAYPAL_SANDBOX', $conf) ? $conf['PAYPAL_SANDBOX'] : '');
		
		$this->_html .= '
		<form action="" method="post">
		<fieldset><legend>'.$this->l('Settings').'</legend>
			<label>'.$this->l('Paypal business e-mail').'</label>
			<div class="margin-form"><input type="text" size="33" name="business" value="'.$business.'" /></div>
			<label>'.$this->l('Sandbox mode').'</label>
			<div class="margin-form">
				<input type="radio" name="sandbox" value="1" '.($sandbox ? 'checked="checked"' : '').' /> '.$this->l('Yes').'
				<input type="radio" name="sandbox" value="0" '.(!$sandbox ? 'checked="checked"' : '').' /> '.$this->l('No').'
			</div>
			<br /><center><input type="submit" name="submitPaypal" value="'.$this->l('Update settings').'" class="button" /></center>			
		</fieldset>
		</form><br /><br />
		<fieldset class="width3"><legend>'.$this->l('Informations').'</legend>
			'.$this->l('In order to use your paypal payment module, you have to configure your paypal account (sandbox account as well as real one). Log in to paypal then:').'<br /><br />
			'.$this->l('In').' Profile > Selling Preferences > Instant Payment Notification Preferences, '.$this->l('set').'<br />
			<b>Instant Payment Notification (IPN)</b> '.$this->l('to').' <b>On</b>,<br />
			<b>Instant Payment Notification (IPN) URL</b> '.$this->l('to').' <b>http://'.$_SERVER['HTTP_HOST'].__PS_BASE_URI__.'modules/'.$this->name.'/validation.php</b>.<br /><br />
			'.$this->l('In').' Profile > Selling Preferences > Website Payment Preferences, '. $this->l('set').'<br />
			<b>Auto Return</b> '.$this->l('to whatever you choose').' (<b>On</b> '.$this->l('is recommended').'),<br />
			<b>Return URL</b> '.$this->l('to').' <b>http://'.$_SERVER['HTTP_HOST'].__PS_BASE_URI__.'order-confirmation.php</b>.<br />
			'.$this->l('Be also sure that').' <b>Payment Data Transfer</b> '.$this->l('is set to').' <b>Off</b>.
		</fieldset>';
	}
	
	public function hookPayment($params)
    {
    	$address = new Address(intval($params['cart']->id_address_invoice));
	 	$customer = new Customer(intval($params['cart']->id_customer));
		$business = Configuration::get('PAYPAL_BUSINESS');

		if (!Validate::isEmail($business))
			return 'Paypal error: (invalid or undefined business account email)';
		
		if (!Validate::isLoadedObject($address) OR !Validate::isLoadedObject($customer))
			return 'Paypal error: (invalid address or customer)';
	 	
		$this->_html = '
		<div class="payment_module">
			<form action="'.$this->_formAction[Configuration::get('PAYPAL_SANDBOX')].'" method="post">
				<input type="hidden" name="upload" value="1" />
				<input type="hidden" name="first_name" value="'.$address->surname.'" />
				<input type="hidden" name="last_name" value="'.$address->name.'" />
				<input type="hidden" name="address1" value="'.$address->address1.'" />'.(!empty($address->address2) ? '<input type="hidden" name="address2" value="'.$address->address2.'" />' : '').'
				<input type="hidden" name="city" value="'.$address->city.'" />
				<input type="hidden" name="zip" value="'.$address->postcode.'" />
				<input type="hidden" name="amount" value="'.number_format($params['cart']->getOrderTotal(true, 4), 2, ',', '').'" />					
				<input type="hidden" name="shipping_1" value="'.$params['cart']->getOrderShippingCost().'" />';
			
			if (!sizeof($params['cart']->getDiscounts()))
			{
				$products = $params['cart']->getProducts();
				$i = 1;
				foreach ($products AS $product)
				{
					$this->_html .= '
					<input type="hidden" name="item_name_'.$i.'" value="'.$product['name'].(isset($product['attribute']) ? ' - '.$product['attribute'] : '').'" />
					<input type="hidden" name="amount_'.$i.'" value="'.$product['price_wt'].'" />
					<input type="hidden" name="quantity_'.$i.'" value="'.intval($product['quantity']).'" />';
					$i++;
				}
			}
			else
			{
				$this->_html .= '
				<input type="hidden" name="item_name_1" value="'.$this->l('My cart').'" />
				<input type="hidden" name="amount_1" value="'.$params['cart']->getOrderTotal(true, 4).'" />
				<input type="hidden" name="quantity_1" value="1" />';
			}
						
			$this->_html .= '
				<input type="hidden" name="business" value="'.$business.'" />
				<input type="hidden" name="receiver_email" value="'.$business.'" />
				<input type="hidden" name="cmd" value="_cart" />
				<input type="hidden" name="charset" value="utf-8" />
				<input type="hidden" name="currency_code" value="EUR" />
				<input type="hidden" name="payer_id" value="'.intval($params['cart']->id_customer).'">
				<input type="hidden" name="payer_email" value="'.$customer->email.'">
				<input type="hidden" name="custom" value="'.intval($params['cart']->id).'" />
				<table><tr><td style="width: 160px; height: 40px;">
				<input type="image" src="'.__PS_BASE_URI__.'modules/'.$this->name.'/paypal.gif" />
				</td><td><b>'.$this->l('Pay with Paypal').'</b></td></tr></table>
			</form>
		</div>';
		
		return $this->_html;
    }
}

?>